@@ -18,7 +18,7 @@
 package org.apache.batik.apps.rasterizer;
 
 import org.apache.batik.test.*;
-import org.apache.batik.test.util.ImageCompareTest;
+import org.apache.batik.test.svg.ImageCompareTest;
 import org.apache.batik.transcoder.Transcoder;
 import org.apache.batik.transcoder.image.ImageTranscoder;
 import org.apache.batik.transcoder.image.JPEGTranscoder;
@@ -35,7 +35,7 @@ import java.util.List;
  * of source and destination sources.
  *
  * @author <a href="mailto:vhardy@apache.org">Vincent Hardy</a>
- * @version $Id: SVGConverterTest.java 1629155 2014-10-03 09:09:09Z vhennebert $
+ * @version $Id: SVGConverterTest.java 1733420 2016-03-03 07:41:59Z gadams $
  */
 public class SVGConverterTest extends DefaultTestSuite {
     public SVGConverterTest(){
