@@ -1,10 +1,11 @@
 /*
 
-   Copyright 2001,2003  The Apache Software Foundation 
-
-   Licensed under the Apache License, Version 2.0 (the "License");
-   you may not use this file except in compliance with the License.
-   You may obtain a copy of the License at
+   Licensed to the Apache Software Foundation (ASF) under one or more
+   contributor license agreements.  See the NOTICE file distributed with
+   this work for additional information regarding copyright ownership.
+   The ASF licenses this file to You under the Apache License, Version 2.0
+   (the "License"); you may not use this file except in compliance with
+   the License.  You may obtain a copy of the License at
 
        http://www.apache.org/licenses/LICENSE-2.0
 
@@ -30,7 +31,7 @@ import java.text.AttributedString;
  *
  * @author <a href="mailto:cjolif@ilog.fr">Christophe Jolif</a>
  * @author <a href="mailto:vhardy@eng.sun.com">Vincent Hardy</a>
- * @version $Id: AttributedCharacterIterator.java,v 1.6 2004/08/18 07:16:43 vhardy Exp $
+ * @version $Id: AttributedCharacterIterator.java 1733420 2016-03-03 07:41:59Z gadams $
  */
 public class AttributedCharacterIterator implements Painter {
     public void paint(Graphics2D g) {
@@ -53,21 +54,28 @@ public class AttributedCharacterIterator implements Painter {
         //
 
         // "Attributed" is in Bold
-        styledText.addAttribute(TextAttribute.WEIGHT, TextAttribute.WEIGHT_BOLD, 0, 10);
+        styledText.addAttribute(TextAttribute.WEIGHT, 
+                                TextAttribute.WEIGHT_BOLD, 0, 10);
 
         // "String" is italic
-        // styledText.addAttribute(TextAttribute.POSTURE, TextAttribute.POSTURE_OBLIQUE, 11, 18);
+        styledText.addAttribute(TextAttribute.POSTURE, 
+                                TextAttribute.POSTURE_OBLIQUE, 11, 18);
 
-        // fun is Bold and underlined
-        styledText.addAttribute(TextAttribute.UNDERLINE, TextAttribute.UNDERLINE_ON, 23, 28);
-        // styledText.addAttribute(TextAttribute.SWAP_COLORS, TextAttribute.SWAP_COLORS_ON);
-        // styledText.addAttribute(TextAttribute.STRIKETHROUGH, TextAttribute.STRIKETHROUGH_ON, 23, 28);
+        // fun is Bold and underlined and strike through
+        styledText.addAttribute(TextAttribute.UNDERLINE, 
+                                TextAttribute.UNDERLINE_ON, 23, 28);
+        styledText.addAttribute(TextAttribute.STRIKETHROUGH, 
+                                TextAttribute.STRIKETHROUGH_ON, 23, 28);
+
+        // styledText.addAttribute(TextAttribute.SWAP_COLORS, 
+        //                         TextAttribute.SWAP_COLORS_ON);
 
         /*TextLayout aLayout = new TextLayout("A", font, frc);
           Shape aShape = aLayout.getOutline(null);
 
           ShapeGraphicAttribute aReplacement = new ShapeGraphicAttribute(aShape, GraphicAttribute.ROMAN_BASELINE, true);
-          styledText.addAttribute(TextAttribute.CHAR_REPLACEMENT, aReplacement, 0, 1);
+          styledText.addAttribute(TextAttribute.CHAR_REPLACEMENT, 
+                                  aReplacement, 0, 1);
 
 
           // Create a BufferedImage to decorate the Shape
@@ -113,16 +121,26 @@ public class AttributedCharacterIterator implements Painter {
         //
 
         // "Attributed" is in dard red
-        styledText.addAttribute(TextAttribute.FOREGROUND, new Color(128, 0, 0), 0, 10);
+        styledText.addAttribute(TextAttribute.FOREGROUND, 
+                                new Color(128, 0, 0), 0, 10);
 
         // "String" is blue
-        styledText.addAttribute(TextAttribute.FOREGROUND, new Color(70, 107, 132), 11, 18);
+        styledText.addAttribute(TextAttribute.FOREGROUND, 
+                                new Color(70, 107, 132), 11, 18);
 
-        // "fun" is yellow on blue background
-        styledText.addAttribute(TextAttribute.FOREGROUND, new Color(236, 214, 70), 23, 28);
-        styledText.addAttribute(TextAttribute.BACKGROUND, new Color(70, 107, 132), 23, 28);
+        // "fun" is yellow
+        styledText.addAttribute(TextAttribute.FOREGROUND, 
+                                new Color(236, 214, 70), 23, 28);
 
         java.text.AttributedCharacterIterator iter = styledText.getIterator();
+        g.drawString(iter, 10, 100);
+
+
+        // "fun" is now yellow on a blue background
+        styledText.addAttribute(TextAttribute.BACKGROUND, 
+                                new Color(70, 107, 132), 23, 28);
+
+        iter = styledText.getIterator();
         /*TextLayout layout = new TextLayout(iter, frc);
 
         Rectangle bounds = layout.getBounds().getBounds();
@@ -130,6 +148,6 @@ public class AttributedCharacterIterator implements Painter {
         bounds.height += 50;
 
         layout.draw(g, 25, layout.getAscent() + 25);*/
-        g.drawString(iter, 10, 100);
+        g.drawString(iter, 10, 130);
     }
 }
