@@ -1,10 +1,11 @@
 /*
 
-   Copyright 2001  The Apache Software Foundation 
-
-   Licensed under the Apache License, Version 2.0 (the "License");
-   you may not use this file except in compliance with the License.
-   You may obtain a copy of the License at
+   Licensed to the Apache Software Foundation (ASF) under one or more
+   contributor license agreements.  See the NOTICE file distributed with
+   this work for additional information regarding copyright ownership.
+   The ASF licenses this file to You under the Apache License, Version 2.0
+   (the "License"); you may not use this file except in compliance with
+   the License.  You may obtain a copy of the License at
 
        http://www.apache.org/licenses/LICENSE-2.0
 
@@ -25,7 +26,7 @@ import java.awt.geom.*;
  *
  * @author <a href="mailto:cjolif@ilog.fr">Christophe Jolif</a>
  * @author <a href="mailto:vhardy@eng.sun.com">Vincent Hardy</a>
- * @version $Id: BStroke.java,v 1.3 2004/08/18 07:16:43 vhardy Exp $
+ * @version $Id: BStroke.java 1733420 2016-03-03 07:41:59Z gadams $
  */
 public class BStroke implements Painter {
     public void paint(Graphics2D g) {
@@ -35,7 +36,7 @@ public class BStroke implements Painter {
         /*
          * Strokes of varying width
          */
-        java.awt.BasicStroke strokesWidth[] = {
+        java.awt.BasicStroke[] strokesWidth = {
             new java.awt.BasicStroke(2.f),
             new java.awt.BasicStroke(4.f),
             new java.awt.BasicStroke(8.f),
@@ -46,7 +47,7 @@ public class BStroke implements Painter {
         /*
          * Strokes of varying termination styles
          */
-        java.awt.BasicStroke strokesCap[] = {
+        java.awt.BasicStroke[] strokesCap = {
             new java.awt.BasicStroke(15.f, java.awt.BasicStroke.CAP_BUTT, java.awt.BasicStroke.JOIN_BEVEL), // No decoration
             new java.awt.BasicStroke(15.f, java.awt.BasicStroke.CAP_SQUARE, java.awt.BasicStroke.JOIN_BEVEL), // Square end
             new java.awt.BasicStroke(15.f, java.awt.BasicStroke.CAP_ROUND, java.awt.BasicStroke.JOIN_BEVEL), // Rounded end
@@ -55,7 +56,7 @@ public class BStroke implements Painter {
         /*
          * Strokes of varying segment connection styles
          */
-        java.awt.BasicStroke strokesJoin[] = {
+        java.awt.BasicStroke[] strokesJoin = {
             new java.awt.BasicStroke(10.f, java.awt.BasicStroke.CAP_SQUARE, java.awt.BasicStroke.JOIN_BEVEL), // Connected with a straight segment
             new java.awt.BasicStroke(10.f, java.awt.BasicStroke.CAP_SQUARE, java.awt.BasicStroke.JOIN_MITER), // Extend outlines until they meet
             new java.awt.BasicStroke(10.f, java.awt.BasicStroke.CAP_SQUARE, java.awt.BasicStroke.JOIN_ROUND), // Round of corner.
@@ -63,7 +64,7 @@ public class BStroke implements Painter {
         /*
          * Strokes of varying miterlimits
          */
-        java.awt.BasicStroke strokesMiter[] = {
+        java.awt.BasicStroke[] strokesMiter = {
             new java.awt.BasicStroke(6.f, java.awt.BasicStroke.CAP_SQUARE, java.awt.BasicStroke.JOIN_MITER, 1),   // Actually cuts of all angles
             new java.awt.BasicStroke(6.f, java.awt.BasicStroke.CAP_SQUARE, java.awt.BasicStroke.JOIN_MITER, 2f),  // Cuts off angles less than 60degrees
             new java.awt.BasicStroke(6.f, java.awt.BasicStroke.CAP_SQUARE, java.awt.BasicStroke.JOIN_MITER, 10f), // Cuts off angles less than 11 degrees
@@ -72,7 +73,7 @@ public class BStroke implements Painter {
         /*
          * Srokes with varying dash styles
          */
-        java.awt.BasicStroke strokesDash[] = {
+        java.awt.BasicStroke[] strokesDash = {
             new java.awt.BasicStroke(8.f,
                             java.awt.BasicStroke.CAP_BUTT,
                             java.awt.BasicStroke.JOIN_BEVEL,
